@@ -22,35 +22,32 @@
 
 #include "filteractionwithaddress.h"
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 //=============================================================================
 // FilterActionForward - forward to
 // Forward message to another user, with a defined template
 //=============================================================================
-class FilterActionForward: public FilterActionWithAddress
+class FilterActionForward : public FilterActionWithAddress
 {
     Q_OBJECT
 public:
     explicit FilterActionForward(QObject *parent = nullptr);
     static FilterAction *newAction();
-    ReturnCode process(ItemContext &context, bool applyOnOutbound) const Q_DECL_OVERRIDE;
-    SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE;
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    void applyParamWidgetValue(QWidget *paramWidget) Q_DECL_OVERRIDE;
-    void setParamWidgetValue(QWidget *paramWidget) const Q_DECL_OVERRIDE;
-    void clearParamWidget(QWidget *paramWidget) const Q_DECL_OVERRIDE;
-    void argsFromString(const QString &argsStr) Q_DECL_OVERRIDE;
-    QString argsAsString() const Q_DECL_OVERRIDE;
-    QString displayString() const Q_DECL_OVERRIDE;
-    bool argsFromStringInteractive(const QString &argsStr, const QString &filterName) Q_DECL_OVERRIDE;
+    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
+    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
+    void applyParamWidgetValue(QWidget *paramWidget) override;
+    void setParamWidgetValue(QWidget *paramWidget) const override;
+    void clearParamWidget(QWidget *paramWidget) const override;
+    void argsFromString(const QString &argsStr) override;
+    Q_REQUIRED_RESULT QString argsAsString() const override;
+    Q_REQUIRED_RESULT QString displayString() const override;
+    Q_REQUIRED_RESULT bool argsFromStringInteractive(const QString &argsStr, const QString &filterName) override;
 
-    QString informationAboutNotValidAction() const Q_DECL_OVERRIDE;
+    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
 private:
     mutable QString mTemplate;
 };
-
 }
 
 #endif
